| From | Subject | Date |
|---|---|---|
| David Woodhouse | [PATCH 18/18] whiteheat: use request_firmware()
Signed-off-by: David Woodhouse <dwmw2@infradead.org>
---
drivers/usb/serial/Kconfig | 8 +
drivers/usb/serial/whiteheat.c | 77 +-
drivers/usb/serial/whiteheat_fw.h | 1669 -----------------------------------
firmware/Makefile | 2 +
firmware/WHENCE | 21 +
firmware/whiteheat.HEX | 1097 +++++++++++++++++++++++
firmware/whiteheat_loader.HEX | 314 +++++++
firmware/whiteheat_loader_debug.HEX | 403 +++++++++
...
| May 30, 6:35 pm 2008 |
| David Woodhouse | [PATCH 17/18] ti_usb_3410_5052: use request_firmware()
Signed-off-by: David Woodhouse <dwmw2@infradead.org>
---
drivers/usb/serial/Kconfig | 17 +
drivers/usb/serial/ti_fw_3410.h | 885 ---------------------------------
drivers/usb/serial/ti_fw_5052.h | 885 ---------------------------------
drivers/usb/serial/ti_usb_3410_5052.c | 40 +-
firmware/Makefile | 3 +
firmware/WHENCE | 15 +
firmware/ti_3410.fw.ihex | 862 ++++++++++++++++++++++++++++++++
firmwar...
| May 30, 11:49 am 2008 |
| David Woodhouse | [PATCH 14/18] keyspan_pda: use request_firmware()
Signed-off-by: David Woodhouse <dwmw2@infradead.org>
---
drivers/usb/serial/Kconfig | 17 +
drivers/usb/serial/keyspan_pda.S | 1124 --------------------------------
drivers/usb/serial/keyspan_pda.c | 51 +-
drivers/usb/serial/keyspan_pda_fw.h | 99 ---
drivers/usb/serial/xircom_pgs.S | 1192 ----------------------------------
drivers/usb/serial/xircom_pgs_fw.h | 103 ---
firmware/Makefile | 2 +
firmware/WHENCE | ...
| May 30, 8:15 am 2008 |
| David Woodhouse | [PATCH 10/18] ihex.h: binary representation of ihex records
Some devices need their firmware as a set of {address, len, data...}
records in some specific order rather than a simple blob.
The normal way of doing this kind of thing is 'ihex', which is a text
format and not entirely suitable for use in the kernel.
This provides a binary representation which is very similar, but much
more compact -- and a helper routine to skip to the next record,
because the alignment constraints mean that everybody will screw it up
for themselves otherwise.
Also a helper...
| May 30, 6:57 am 2008 |
| Jeremy Fitzhardinge | [PATCH 0 of 5] xen device driver updates
Hi,
This is a series of cleanups to xen-blkfront, xen-netfront and xenbus.
They're mostly changes imported from the linux-2.6.18-xen repo because
they looked like they would be useful.
Thanks,
J
drivers/block/xen-blkfront.c | 48 ++++++++++++++++++++++++++---
drivers/net/xen-netfront.c | 4 +-
drivers/xen/xenbus/xenbus_client.c | 2 -
drivers/xen/xenbus/xenbus_xs.c | 10 +++---
4 files changed, 52 insertions(+), 12 deletions(-)
--
| May 30, 7:50 pm 2008 |
| Jeremy Fitzhardinge | [PATCH 5 of 5] xen: Avoid allocations causing swap activity ...
From: Ian Campbell <ian.campbell@citrix.com>
Avoid allocations causing swap activity on the resume path by allowing
such allocations to access the emergency pools otherwise a
save/restore/migration of a guest which is low on memory can
deadlock.
[ linux-2.6.18-xen changesets e8b49cfbdac, fdb998e79aba ]
Signed-off-by: Ian Campbell <ian.campbell@citrix.com>
Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
---
drivers/block/xen-blkfront.c | 5 +++-...
| May 30, 7:50 pm 2008 |
| Jeremy Fitzhardinge | [PATCH 2 of 5] xn/blkfront: Add the CDROM_GET_CAPABILITY ioc...
From: Christian Limpach <Christian.Limpach@xensource.com>
Return 0 instead of -EINVAL if the blkfront device is a cdrom,
i.e. had the VDISK_CDROM attribute. This allows udev's cdrom_id
to correctly detect the device as a cdrom device.
[ Add blkif_ioctl, and CDROMMULTISESSION ]
[ linux-2.6.18-xen changeset d2bd9af846b5 ]
Signed-off-by: Christian Limpach <Christian.Limpach@xensource.com>
Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
---
drivers/block/...
| May 30, 7:50 pm 2008 |
| Jeremy Fitzhardinge | [PATCH 1 of 5] xen/blkfront: Make sure we don't use bounce b...
From: Ian Campbell <ian.campbell@xensource.com>
[ linux-2.6.18-xen changeset 667228bf8fc5 ]
Signed-off-by: Ian Campbell <ian.campbell@xensource.com>
Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
---
drivers/block/xen-blkfront.c | 3 +++
1 file changed, 3 insertions(+)
diff --git a/drivers/block/xen-blkfront.c b/drivers/block/xen-blkfront.c
--- a/drivers/block/xen-blkfront.c
+++ b/drivers/block/xen-blkfront.c
@@ -324,6 +324,9 @@
/* Make sure buff...
| May 30, 7:50 pm 2008 |
| Jeremy Fitzhardinge | [PATCH 4 of 5] xen/blkfront: add __exit to module_exit() han...
From: Jan Beulich <jbeulich@novell.com>
Signed-off-by: Jan Beulich <jbeulich@novell.com>
Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
---
drivers/block/xen-blkfront.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/drivers/block/xen-blkfront.c b/drivers/block/xen-blkfront.c
--- a/drivers/block/xen-blkfront.c
+++ b/drivers/block/xen-blkfront.c
@@ -1045,7 +1045,7 @@
module_init(xlblk_init);
-static void xlblk_exit(void)
+st...
| May 30, 7:50 pm 2008 |
| Jeremy Fitzhardinge | [PATCH 3 of 5] xen/blkfront: Make sure that the device is fu...
From: Wim Colgate <wim@xensource.com>
[ linux-2.6.18-xen changeset c1c57fea77e9 ]
Signed-off-by: Wim Colgate <wim@xensource.com>
Signed-off-by: Jeremy Fitzhardinge <jeremy.fitzhardinge@citrix.com>
---
drivers/block/xen-blkfront.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/drivers/block/xen-blkfront.c b/drivers/block/xen-blkfront.c
--- a/drivers/block/xen-blkfront.c
+++ b/drivers/block/xen-blkfront.c
@@ -997,7 +997,7 @@
struct xenbus_device ...
| May 30, 7:50 pm 2008 |
| Alexey Dobriyan | netsc520 remapping RAM
Steps to reproduce:
modprobe netsc520
NetSc520 flash device: 0x100000 at 0x200000
------------[ cut here ]------------
WARNING: at arch/x86/mm/ioremap.c:159 __ioremap_caller+0x15e/0x2c0()
Modules linked in: netsc520(+) [many]
Pid: 13101, comm: modprobe Not tainted 2.6.26-rc4-fat #6
Call Trace:
[<ffffffff80238042>] warn_on_slowpath+0x58/0x88
[<ffffffff80238c7e>] ? printk+0x67/0x69
[<ffffffff80222adc>] __ioremap_caller+0x15e/0x2c0
[<ffffffffa1fab033>] ? :netsc520:...
| May 30, 7:38 pm 2008 |
| Alexey Dobriyan | [PATCH] isdn divas: fix proc creation
1. creating proc entry and not saving pointer to PDE and checking it
is not going to work.
2. if proc entry wasn't created, no reason to remove it on error path.
Signed-off-by: Alexey Dobriyan <adobriyan@gmail.com>
---
drivers/isdn/hardware/eicon/divasmain.c | 1 -
drivers/isdn/hardware/eicon/divasproc.c | 4 ++--
2 files changed, 2 insertions(+), 3 deletions(-)
--- a/drivers/isdn/hardware/eicon/divasmain.c
+++ b/drivers/isdn/hardware/eicon/divasmain.c
@@ -806,7 +806,6 @@ sta...
| May 30, 7:34 pm 2008 |
| Alexey Dobriyan | [PATCH] edd: fix suspicious return of 1 from module_init
Signed-off-by: Alexey Dobriyan <adobriyan@gmail.com>
---
drivers/firmware/edd.c | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
--- a/drivers/firmware/edd.c
+++ b/drivers/firmware/edd.c
@@ -753,7 +753,7 @@ edd_init(void)
if (!edd_num_devices()) {
printk(KERN_INFO "EDD information not available.\n");
- return 1;
+ return -ENODEV;
}
edd_kset = kset_create_and_add("edd", NULL, firmware_kobj);
--
| May 30, 7:29 pm 2008 |
| Bjorn Helgaas | [patch 15/15] PNP: convert resource options to single linked...
ISAPNP, PNPBIOS, and ACPI describe the "possible resource settings" of
a device, i.e., the possibilities an OS bus driver has when it assigns
I/O port, MMIO, and other resources to the device.
PNP used to maintain this "possible resource setting" information in
one independent option structure and a list of dependent option
structures for each device. Each of these option structures had lists
of I/O, memory, IRQ, and DMA resources, for example:
dev
independent options
ind-io0 ->...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 14/15] PNP: support optional IRQ resources
This patch adds an IORESOURCE_IRQ_OPTIONAL flag for use when
assigning resources to a device. If the flag is set and we are
unable to assign an IRQ to the device, we can leave the IRQ
disabled but allow the overall resource allocation to succeed.
Some devices request an IRQ, but can run without an IRQ
(possibly with degraded performance). This flag lets us run
the device without the IRQ instead of just leaving the
device disabled.
This is a reimplementation of this previous change by Rene
Her...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 11/15] PNP: centralize resource option allocations
This patch moves all the option allocations (pnp_mem, pnp_port, etc)
into the pnp_register_{mem,port,irq,dma}_resource() functions. This
will make it easier to rework the option data structures.
The non-trivial part of this patch is the IRQ handling. The backends
have to allocate a local pnp_irq_mask_t bitmap, populate it, and pass
a pointer to pnp_register_irq_resource().
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
---
drivers/pnp/base.h | 12 ++-
drivers/pnp/i...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 13/15] PNP: rename pnp_register_*_resource() local va...
No functional change; just rename "data" to something more
descriptive.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/resource.c
===================================================================
--- work10.orig/drivers/pnp/resource.c 2008-05-20 13:23:06.000000000 -0600
+++ work10/drivers/pnp/resource.c 2008-05-20 13:24:27.000000000 -0600
@@ -80,40 +80,40 @@ struct pnp_option *pnp_register_dependen
int pnp_register_irq_resource(struct pnp_dev *dev, struct ...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 12/15] PNPACPI: ignore _PRS interrupt numbers larger ...
ACPI Extended Interrupt Descriptors can encode 32-bit interrupt
numbers, so an interrupt number may exceed the size of the bitmap
we use to track possible IRQ settings.
To avoid corrupting memory, complain and ignore too-large interrupt
numbers.
There's similar code in pnpacpi_parse_irq_option(), but I didn't
change that because the small IRQ descriptor can only encode
IRQs 0-15, which do not exceed bitmap size.
In the future, we could handle IRQ numbers greater than PNP_IRQ_NR
by replacing t...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 06/15] PNP: increase I/O port & memory option add...
ACPI Address Space Descriptors can be up to 64 bits wide.
We should keep track of the whole thing when parsing resource
options, so this patch changes PNP port and mem option
fields from "unsigned short" and "unsigned int" to
"resource_size_t".
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
---
drivers/pnp/base.h | 16 ++++++++--------
drivers/pnp/interface.c | 17 +++++++++++------
drivers/pnp/resource.c | 14 ++++++++++----
3 files changed, 29 insertions(+), 18 deleti...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 09/15] PNP: make resource assignment functions return...
This patch doesn't change any behavior; it just makes the return
values more conventional.
This changes pnp_assign_dma() from a void function to one that
returns an int, just like the other assignment functions. For
now, at least, pnp_assign_dma() always returns 0 (success), so
it appears to never fail, just like before.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/manager.c
===================================================================
--- work10....
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 10/15] PNP: remove redundant pnp_can_configure() check
pnp_assign_resources() is static and the only caller checks
pnp_can_configure() before calling it, so no need to do it
again.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/manager.c
===================================================================
--- work10.orig/drivers/pnp/manager.c 2008-05-13 13:29:57.000000000 -0600
+++ work10/drivers/pnp/manager.c 2008-05-13 13:30:21.000000000 -0600
@@ -231,9 +231,6 @@ static int pnp_assign_resources(struct p
struc...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 08/15] PNP: in debug resource dump, make empty list o...
If the resource list is empty, say that explicitly. Previously,
it was confusing because often the heading was followed by zero
resource lines, then some "add resource" lines from auto-assignment,
so the "add" lines looked like current resources.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/support.c
===================================================================
--- work10.orig/drivers/pnp/support.c 2008-05-16 16:01:26.000000000 -0600
+++ work10/drive...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 07/15] PNP: improve resource assignment debug
When we fail to assign an I/O or MEM resource, include the min/max
in the debug output to help match it with the options.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/manager.c
===================================================================
--- work10.orig/drivers/pnp/manager.c 2008-05-13 12:01:17.000000000 -0600
+++ work10/drivers/pnp/manager.c 2008-05-13 12:50:57.000000000 -0600
@@ -47,7 +47,10 @@ static int pnp_assign_port(struct pnp_de
res->st...
| May 30, 6:49 pm 2008 |
| Bjorn Helgaas | [patch 05/15] PNP: introduce pnp_irq_mask_t typedef
This adds a typedef for the IRQ bitmap, which should cause
no functional change, but will make it easier to pass a
pointer to a bitmap to pnp_register_irq_resource().
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/base.h
===================================================================
--- work10.orig/drivers/pnp/base.h 2008-05-30 13:20:29.000000000 -0600
+++ work10/drivers/pnp/base.h 2008-05-30 13:20:36.000000000 -0600
@@ -30,8 +30,10 @@ struct pnp_port {
...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 03/15] PNP: define PNP-specific IORESOURCE_IO_* flags...
PNP previously defined PNP_PORT_FLAG_16BITADDR and PNP_PORT_FLAG_FIXED
in a private header file, but put those flags in struct resource.flags
fields. Better to make them IORESOURCE_IO_* flags like the existing
IRQ, DMA, and MEM flags.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
---
include/linux/ioport.h | 10 +++++++---
include/linux/pnp.h | 3 ---
drivers/pnp/interface.c | 2 +-
drivers/pnp/isapnp/core.c | 4 ++--
drivers/pnp/pnpacpi/...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 04/15] PNP: make resource option structures private t...
Nothing outside the PNP subsystem should need access to a
device's resource options, so this patch moves the option
structure declarations to a private header file.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/base.h
===================================================================
--- work10.orig/drivers/pnp/base.h 2008-05-16 16:10:32.000000000 -0600
+++ work10/drivers/pnp/base.h 2008-05-16 16:10:56.000000000 -0600
@@ -19,6 +19,54 @@ void pnp_remove_card...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 02/15] PNP: whitespace/coding style fixes
No functional change; just make a couple declarations
consistent with the rest of the file.
Signed-off-by: Bjorn Helgaas <bjorn.helgaas@hp.com>
Index: work10/drivers/pnp/interface.c
===================================================================
--- work10.orig/drivers/pnp/interface.c 2008-05-09 14:42:25.000000000 -0600
+++ work10/drivers/pnp/interface.c 2008-05-09 14:45:57.000000000 -0600
@@ -216,12 +216,12 @@ static ssize_t pnp_show_options(struct d
struct device_attribute *attr...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 01/15] serial: when guessing, check only active resou...
Given a completely unknown PNP device, if it happens to have
a modem-like string in its name and it matches a COM port
address, we assume it's a modem.
We used to check the address against all the possible resource
options for the device. But the device is already configured
and enabled, so we only need to check the resources it is
actually using. If we matched an address that wasn't currently
enabled, we would fail anyway as soon as we attempted to touch
the device at that address.
This remo...
| May 30, 6:48 pm 2008 |
| Bjorn Helgaas | [patch 00/15] PNP: convert resource options to unified dynam...
This patch series converts the PNP resource option structures
to a unified linked list. This preserves resource order, which
is important for some devices. There's more detail in the
comments for the last patch.
Any comments would be welcome.
This depends on some patches that are in -mm, but not yet
upstream. In mmotm, these would probably go after
pnp-dont-sort-by-type-in-sys-resources.patch
Bjorn
--
--
| May 30, 6:48 pm 2008 |
| Ahmed S. Darwish | [PATCH BUGFIX -rc4] Smack: Respect 'unlabeled' netlabel mode
Hi all,
In case of Smack 'unlabeled' netlabel option, Smack passes a _zero_
initialized 'secattr' to label a packet/sock. This causes an
[unfound domain label error]/-ENOENT by netlbl_sock_setattr().
Above Netlabel failure leads to Smack socket hooks failure causing
an always-on socket() -EPERM error.
Such packets should have a netlabel domain agreed with netlabel to
represent unlabeled packets. Fortunately Smack net ambient label
packets are agreed with netlabel to be treated as unlabeled p...
| May 30, 7:36 pm 2008 |
| Casey Schaufler | Re: [PATCH BUGFIX -rc4] Smack: Respect 'unlabeled' netlabel ...
To date the behavior of a Smack system running with nltype
unlabeled has been carefully undefined. The way you're defining
it will result in a system in which only processes running with
the ambient label will be able to use sockets, unless I'm reading
the code incorrectly. This seems like "correct" behavior, but
I don't think it is what those who've tried it would expect.
Casey Schaufler
casey@schaufler-ca.com
--
| May 30, 7:10 pm 2008 |
| Ahmed S. Darwish | [PATCH BUGFIX -v2 -rc4] Smack: Respect 'unlabeled' netlabel ...
Hi!,
[ Sorry, Fix: Acquire smack_ambient_lock before reading smack_net_ambient ]
-->
In case of Smack 'unlabeled' netlabel option, Smack passes a _zero_
initialized 'secattr' to label a packet/sock. This causes an
[unfound domain label error]/-ENOENT by netlbl_sock_setattr().
Above Netlabel failure leads to Smack socket hooks failure causing
an always-on socket() -EPERM error.
Such packets should have a netlabel domain agreed with netlabel to
represent unlabeled packets. Fortunately S...
| May 30, 7:57 pm 2008 |
| Casey Schaufler | Re: [PATCH BUGFIX -v2 -rc4] Smack: Respect 'unlabeled' netla...
This is truely awful. I suggest that instead of doing this
locking you disallow changes to the ambient label if the
nltype is not a well handled type, that is, CIPSO. The overhead
you're introducing to handle a case that will cause the system
to be pretty well useless (if ambient isn't the floor label
Casey Schaufler
casey@schaufler-ca.com
--
| May 30, 7:45 pm 2008 |
| Andrew Morton | Re: [PATCH BUGFIX -v2 -rc4] Smack: Respect 'unlabeled' netla...
On Sat, 31 May 2008 02:57:51 +0300
no no no no no. And no.
GFP_ATOMIC is *unreliable*. Using it in a "security" feature is a bug
- if it fails, the feature isn't secure any more.
Failing to check the kmalloc() return value might be a bug.
If we _need_ GFP_ATOMIC here then taking a mutex in a cannot-sleep
context is a bug.
The patch adds a kmalloc but doesn't add a kfree. Is it leaky?
Finally, why is there a need to take a lock around a single store
instruction?
--
| May 30, 7:25 pm 2008 |
| Tetsuo Handa | Re: [PATCH BUGFIX -v2 -rc4] Smack: Respect 'unlabeled' netla...
Hello.
Getting a mutex lock might sleep, so why not use GFP_KERNEL ?
--
| May 30, 7:10 pm 2008 |
| Paul Jackson | [PATCH v2] doc: document the kernel-doc conventions for kern...
From: Paul Jackson <pj@sgi.com>
Provide documentation of the kernel-doc documentation conventions
oriented to kernel hackers.
Since I figure that there will be more people reading this
kernel-doc-nano-HOWTO.txt file who are kernel developers focused
on the rest of the kernel, than there will be readers of this
file who are documentation developers extracting that embedded
kernel-doc documentation, I have taken the liberty of making
the new section added here:
How to format kernel-doc ...
| May 30, 6:19 pm 2008 |
| Jeff Garzik | [git patches] libata fixes
Please pull from 'upstream-linus' branch of
master.kernel.org:/pub/scm/linux/kernel/git/jgarzik/libata-dev.git upstream-linus
to receive the following updates:
drivers/ata/ahci.c | 8 +-
drivers/ata/ata_piix.c | 7 +-
drivers/ata/libata-core.c | 2 +-
drivers/ata/libata-pmp.c | 7 +-
drivers/ata/libata-scsi.c | 3 +-
drivers/ata/sata_fsl.c | 224 ++++++++++++++++++++++++++++++++------------
drivers/ata/sata_mv.c | 83 ++++++++---------
7 files changed, 21...
| May 30, 6:13 pm 2008 |
| Clifford Wolf | [PATCH] Add rlimits to /proc/<PID>/status
Signed-off-by: Clifford Wolf <clifford@clifford.at>
---
fs/proc/array.c | 57 +++++++++++++++++++++++++++++++++++++++++++++++++++++++
1 files changed, 57 insertions(+), 0 deletions(-)
diff --git a/fs/proc/array.c b/fs/proc/array.c
index 9e3b8c3..3cb2ad3 100644
--- a/fs/proc/array.c
+++ b/fs/proc/array.c
@@ -242,6 +242,62 @@ static void collect_sigign_sigcatch(struct task_struct *p, sigset_t *ign,
}
}
+static const char *rlim_names[RLIM_NLIMITS] = {
+ [RLIMIT_CPU] = "CPU",...
| May 30, 4:11 pm 2008 |
| Peter Zijlstra | Re: [PATCH] Add rlimits to /proc/<PID>/status
fs/proc/base.c already has an array with strings in it
--
| May 30, 5:14 pm 2008 |
| Johannes Weiner | [PATCH -mm 14/14] bootmem: replace node_boot_start in struct...
Almost all users of this field need a PFN instead of a physical
address, so replace node_boot_start with node_min_pfn.
Signed-off-by: Johannes Weiner <hannes@saeureba.de>
CC: linux-arch@vger.kernel.org
---
arch/alpha/mm/numa.c | 2 +-
arch/arm/plat-omap/fb.c | 4 +---
arch/avr32/mm/init.c | 3 +--
arch/ia64/mm/discontig.c | 19 ++++++++++---------
arch/m32r/mm/discontig.c | 3 +--
arch/m32r/mm/init.c | 4 +---
arch/mn10300/mm/init.c | 6 +++---
arch...
| May 30, 3:42 pm 2008 |
| Johannes Weiner | [PATCH -mm 13/14] bootmem: revisit alloc_bootmem_section
Since alloc_bootmem_core does no goal-fallback anymore and just
returns NULL if the allocation fails, we might now use it in
alloc_bootmem_section without all the fixup code for a misplaced
allocation.
Also, the limit can be the first PFN of the next section as the
semantics is that the limit is _above_ the allocated region, not
within.
Signed-off-by: Johannes Weiner <hannes@saeurebad.de>
CC: Yasunori Goto <y-goto@jp.fujitsu.com>
---
mm/bootmem.c | 27 ++++++-------------------...
| May 30, 3:42 pm 2008 |
| Johannes Weiner | [PATCH -mm 12/14] bootmem: Make __alloc_bootmem_low_node fal...
__alloc_bootmem_node already does this, make the interface consistent.
Signed-off-by: Johannes Weiner <hannes@saeurebad.de>
CC: Ingo Molnar <mingo@elte.hu>
CC: Yinghai Lu <yhlu.kernel@gmail.com>
CC: Andi Kleen <andi@firstfloor.org>
---
mm/bootmem.c | 25 ++++++++++++++++---------
1 file changed, 16 insertions(+), 9 deletions(-)
--- a/mm/bootmem.c
+++ b/mm/bootmem.c
@@ -595,6 +595,19 @@ void * __init __alloc_bootmem_low(unsign
return ___alloc_bootmem(size, align,...
| May 30, 3:42 pm 2008 |
| Johannes Weiner | [PATCH -mm 11/14] bootmem: respect goal more likely
The old node-agnostic code tried allocating on all nodes starting from
the one with the lowest range. alloc_bootmem_core retried without the
goal if it could not satisfy it and so the goal was only respected at
all when it happened to be on the first (lowest page numbers) node (or
theoretically if allocations failed on all nodes before to the one
holding the goal).
Introduce a non-panicking helper that starts allocating from the node
holding the goal and falls back only after all thes tries failed...
| May 30, 3:42 pm 2008 |
| Johannes Weiner | Re: [PATCH -mm 11/14] bootmem: respect goal more likely
Hi,
Sorry, forgot to update ->last_success handling here. Update coming soon.
Hannes
--
| May 30, 5:46 pm 2008 |
| Hugh Dickins | Re: [PATCH] Add rlimits to /proc/<PID>/status
Aren't they better staying in /proc/<PID>/limits?
Hugh
--
| May 30, 5:35 pm 2008 |
| Clifford Wolf | Re: [PATCH] Add rlimits to /proc/<PID>/status
Hi,
this was a cleanup of a patch I've sent to lkml about 6 months ago
when there was no yet-released (non-rc) kernel with /proc/<PID>/limits ...
my patch is a more or less duplicate of commit d85f50d5. oops.
please simply ignore it.. ;-)
yours,
- clifford
--
A byte walks into a bar and orders a pint. Bartender asks him "What's wrong?"
Byte says "Parity error." Bartender nods and says "Yeah, I thought you looked
a bit off."
--
| May 30, 6:50 pm 2008 |
| Stefanik Gábor | "BUG: unable to handle kernel paging request" on shutdown or...
I have just compiled a kernel from wireless-testing (32-bit x86), and
I get this during shutdown or if I kill NetworkManager (blacklisting
rt73usb fixes it):
BUG: unable to handle kernel paging request at 0000759d
IP: [<f8ac8f77>] :usbcore:usb_kill_urb+0x17/0xd0
*pdpt = 00000000354d2001 *pde = 0000000000000000
Oops: 0000 [#1] SMP
Modules linked in: ocfs2_dlmfs ocfs2_dlm ocfs2_nodemanager configfs
ipv6 af_packet microcode rfkill_input binfmt_misc snd_pcm_oss
snd_mixer_oss snd_seq snd_seq_dev...
| May 30, 4:36 pm 2008 |
| Ivo van Doorn | Re: "BUG: unable to handle kernel paging request" on shutdow...
Could you try below patch to see if that works?
Ivo
---
diff --git a/drivers/net/wireless/rt2x00/rt2x00usb.c b/drivers/net/wireless/rt2x00/rt2x00usb.c
index 58d1633..63381cf 100644
--- a/drivers/net/wireless/rt2x00/rt2x00usb.c
+++ b/drivers/net/wireless/rt2x00/rt2x00usb.c
@@ -347,8 +347,11 @@ void rt2x00usb_disable_radio(struct rt2x00_dev *rt2x00dev)
}
/*
* Kill guardian urb.
*/
+ if (!test_bit(DRIVER_REQUIRE_BEACON_GUARD, &...
| May 30, 5:06 pm 2008 |
| Paul Jackson | [PATCH] doc: document the kernel-doc conventions for kernel ...
From: Paul Jackson <pj@sgi.com>
Provide documentation of the kernel-doc documentation conventions
oriented to kernel hackers.
Since I figure that there will be more people reading this
kernel-doc-nano-HOWTO.txt file who are kernel developers focused
on the rest of the kernel, than there will be readers of this
file who are documentation developers extracting that embedded
kernel-doc documentation, I have taken the liberty of making
the new section added here:
How to format kernel-doc ...
| May 30, 4:34 pm 2008 |
| Randy Dunlap | Re: [PATCH] doc: document the kernel-doc conventions for ker...
Yes, that comment is correct. And unfortunate. We need some way to provide
Please fix the few typos and add Acked-by: Randy Dunlap <rdunlap@xenotime.net>.
Thanks, Paul.
---
~Randy
"He closes his eyes and drops the goggles. You can't get hurt
by looking at a bitmap. Or can you?"
@@ -347,8 +347,11 @@ void rt2x00usb_disable_radio(struct rt2x00_dev *rt2x00dev)
}
/*
- * Kill guardian urb.
+ * Kill guardian urb (if required by driver).
*/
--
| May 30, 4:16 pm 2008 |
| previous day | today | next day |
|---|---|---|
| May 29, 2008 | May 30, 2008 | May 31, 2008 |
| Theodore Tso | Re: -mm merge plans for 2.6.23 -- sys_fallocate |
| Greg Kroah-Hartman | [PATCH 005/196] Chinese: add translation of SubmittingDrivers |
| Christoph Hellwig | Re: [malware-list] [RFC 0/5] [TALPA] Intro to a linux interface for on access scan... |
| Andi Kleen | [PATCH] [0/45] x86 2.6.24 patches review I |
git: | |
| Wenji Wu | RE: A Linux TCP SACK Question |
| David Miller | Re: [PATCH] pkt_sched: Destroy gen estimators under rtnl_lock(). |
| David Miller | Re: [GIT]: Networking |
